package Sah::Schemas::GraphicsColorNames;

our $DATE = '2021-03-18'; # DATE
our $VERSION = '0.003'; # VERSION

1;
# ABSTRACT: Sah schemas related to Graphics::ColorNames

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::Schemas::GraphicsColorNames - Sah schemas related to Graphics::ColorNames

=head1 VERSION

This document describes version 0.003 of Sah::Schemas::GraphicsColorNames (from Perl distribution Sah-Schemas-GraphicsColorNames), released on 2021-03-18.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-GraphicsColorNames>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-GraphicsColorNames>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Sah-Schemas-GraphicsColorNames/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Sah> - specification

L<Data::Sah>

L<Graphics::ColorNames>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2020 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
